summaryrefslogtreecommitdiff
path: root/plugins/externaltools/tools/outputpanel.py
diff options
context:
space:
mode:
Diffstat (limited to 'plugins/externaltools/tools/outputpanel.py')
-rwxr-xr-xplugins/externaltools/tools/outputpanel.py6
1 files changed, 3 insertions, 3 deletions
diff --git a/plugins/externaltools/tools/outputpanel.py b/plugins/externaltools/tools/outputpanel.py
index a30aad72..9d1da65f 100755
--- a/plugins/externaltools/tools/outputpanel.py
+++ b/plugins/externaltools/tools/outputpanel.py
@@ -1,5 +1,5 @@
# -*- coding: utf-8 -*-
# Gedit External Tools plugin
# Copyright (C) 2005-2006 Steve Frécinaux <[email protected]>
# Copyright (C) 2010 Per Arneng <[email protected]>
#
@@ -19,7 +19,7 @@
__all__ = ('OutputPanel', 'UniqueById')
-import gtk, gedit
+import gtk, pluma
import pango
import gobject
import os
@@ -217,7 +217,7 @@ class OutputPanel(UniqueById):
gfile = self.file_lookup.lookup(link.path)
if gfile:
- gedit.commands.load_uri(self.window, gfile.get_uri(), None,
+ pluma.commands.load_uri(self.window, gfile.get_uri(), None,
link.line_nr)
gobject.idle_add(self.idle_grab_focus)
@@ -1,5 +1,5 @@
# -*- coding: utf-8 -*-
-# Gedit External Tools plugin
+# Pluma External Tools plugin
# Copyright (C) 2005-2006 Steve Frécinaux <[email protected]>
# Copyright (C) 2010 Per Arneng <[email protected]>